// shoppingGuid/page/pages/taskNotice/taskNotice.js
const wxService = require('../../../../utils/wxService')
import { Integer } from '../../../../utils/integerDigitalConvertion'
const app = getApp();
wxService.page({
  /**
   * 页面的初始数据
   */
  data: {
    notice : [],
    nodata : false,
    goods : {
      goodsList : []
    },
    showShareModel: false,
    shareModelObj: {
      title: '',
      imageUrl: '',
      path: ''
    },
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu();
    let id = options.id , 
      type = options.type;
    this.getTaskInfo(id,type);
  },
  //获取任务详情
  getTaskInfo(id,type){
    wx.showLoading({
      title: '加载中'
    });
    wxService.post(`/marketing/shoppingguide/task/detail?orderType=${type}&taskId=${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          let notice = data.task.notice ? JSON.parse(data.task.notice) : [];
          if(notice.length == 0){
            this.data.nodata = true;
          }
          else{
            this.data.nodata = false;
          }

          let products = data.task.product ? JSON.parse(data.task.product) : [];
          if(products.length > 0){
            let proIds = products.map(item => {
              return item.id;
            });
            this.getProductsList(proIds);
          }

          this.setData({
            notice: notice,
            nodata: this.data.nodata
          });
        }
      }
    })
  },

  //跳转到商品详情
  onTapToGoodsDetail(e) {
    let item = e.currentTarget.dataset.item;
    let productId = item.productId;
    wx.navigateTo({
      url: '/pages/productDetail/productDetail?id=' + productId,
    });
  },

  //根据商品ids获取商品列表
  getProductsList(proIds){
    wx.showLoading({
      title: '获取商品信息中..',
    });
    wxService.post(`/sale/product/listPage?pageNo=1&pageSize=10000`,{
      productIds : proIds
    }).then(res => {
      if(res){
        let list = res.data.data.content ? res.data.data.content : [];
        this.data.goods.goodsList = list;
        list.forEach(item => {
          item.price = parseFloat(item.minSalePrice/10/10).toFixed(2);
          item.productImgUrl = item.indexUrl;
        });

        this.setData({
          goods : this.data.goods
        });
      }
    })
  },

  //定向发送
  //定向转发商品给用户 分享功能
  onTapToShare(e) {
    let item = e.currentTarget.dataset.item;
    // 生成触点对象
    let content = {
      title: item.productName,
      id: item.productId,
      url: item.productImgUrl
    }
    let tentacleInfo = {
      content: JSON.stringify(content),
      contentId: item.productId,
      contentType: app.globalData.contants.SHARE_TYPE.PRODUCT_DETAIL, //内容类型 
      title: item.productName, //标题
      type: 3// 1:门店,2:员工(暂时不做),3:会员,4:第三方外部渠道,5:智能营销
    }

    wxService.getTentacleContent(tentacleInfo).then(res => {
      if (res && res.id) {
        let tentacleId = res.id;
        let inner_id = Integer.digit(item.productId, 10, 64);
        let inner_tentacleId = Integer.digit(tentacleId, 10, 64);
        var path = 'pages/productDetail/productDetail' + '?i=' + inner_id + '&t=' + inner_tentacleId;
        this.data.shareModelObj.title = item.productName;
        this.data.shareModelObj.imageUrl = item.productImgUrl;
        this.data.shareModelObj.path = path;

        this.setData({
          shareModelObj: this.data.shareModelObj,
          showShareModel: true,
        });

      }
    });
  },

  //立即群发商品给用户
  onTapToRecommandProduct(e) {
    let item = e.currentTarget.dataset.item;
    // 生成触点对象
    let content = {
      title: item.productName,
      id: item.productId,
      url: item.productImgUrl
    }
    let tentacleInfo = {
      content: JSON.stringify(content),
      contentId: item.productId,
      contentType: app.globalData.contants.SHARE_TYPE.PRODUCT_DETAIL, //内容类型 
      title: item.productName, //标题
      type: 3// 1:门店,2:员工(暂时不做),3:会员,4:第三方外部渠道,5:智能营销
    }

    wxService.getTentacleContent(tentacleInfo).then(res => {
      if (res && res.id) {
        let tentacleId = res.id;
        let inner_id = Integer.digit(item.productId, 10, 64);
        let inner_tentacleId = Integer.digit(tentacleId, 10, 64);
        var path = 'pages/productDetail/productDetail' + '?i=' + inner_id + '&t=' + inner_tentacleId;
        //打开企业微信通讯录选择会员
        wx.qy.shareToExternalContact({
          appid: app.globalData.appId,//小程序的appid
          title: item.productName, //小程序消息的title
          imgUrl: item.productImgUrl,//小程序消息的封面图
          page: path, //小程序消息打开后的路径
          success: function (res) {
            wx.showToast({
              title: '推荐成功！'
            });
          },
          fail: function (err) {
            console.log('error---------------', err);
          }
        });
      }
    });
  },

  //取消分享
  onTapCancelShare() {
    this.setData({
      showShareModel: false,
    });
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function (res) {
    if (res.from == 'button') {
      return {
        title: this.data.shareModelObj.title,
        path: this.data.shareModelObj.path,
        imageUrl: this.data.shareModelObj.imageUrl
      }
    }
  }
  
})