// share/share.js
const wxService = require('../../../../utils/wxService')
const utils = require('../../../../utils/util')
const envInfo = require('../../../../config/index').envInfo
const app = getApp()
const deviceWidth = app.globalData.systemInfo.windowWidth;
console.log(app.globalData.systemInfo)
const isIPX = app.globalData.systemInfo.model == 'iPhone X';
console.log(isIPX)
let deviceHeight = app.globalData.systemInfo.windowHeight;
const ratio = deviceWidth / deviceHeight;
// 单位转换
const rpx2px = rpx => deviceWidth / 750 * rpx

/**
 * 设置文本行数，超出省略
 * @param {object} ctx canvas实例
 * @param {string} text 文本数据
 * @param {number} lineNum 行数
 * @param {number} width 文字宽度最宽默认 620rpx
 * 返回 由每一行组成的数组
 */
const setTextLine = (ctx, text, lineNum = 1, width = 610) => {
  const str_arr = String(text).split('')
  width = rpx2px(width)
  let temp = ''
  // 分行
  let row_arr = str_arr.reduce((arr, word) => {
    const w = ctx.measureText(temp).width
    if (w < width) {
      temp += word;
    } else {
      arr.push(temp)
      temp = word
    }
    return arr
  }, [])
  row_arr.push(temp)
  temp = ''

  // 判断需要的行数
  row_arr = row_arr.slice(0, lineNum)
  if (row_arr.length > 1) {
    // 最后一行超出则省略号
    row_arr[row_arr.length - 1].split().every(v => {
      temp += v
      if (ctx.measureText(temp).width > (width - 20)) {
        temp += '...'
        return false
      }
      return true
    })
    row_arr.splice(row_arr.length - 1, 1, temp)
  }

  return row_arr
}

wxService.page({

  /**
   * 页面的初始数据
   */
  data: {
    shareLogo: envInfo.shareLogo,
    shareTitle: envInfo.shareTitle,
    productImg: '',
    qrcodeImg: '',
    product: {
      productName: '',
      price: '',
      productId: '',
      type : '',
    },
    tempShareLogo: '',
    username: '',
    height: '1100rpx',
    canvasTempFileUrl: '',
    btnIsDisabled: true,
    isInput : false,
    inputText : '',
    sourceText : '',

  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let shareInfo = options.shareInfo ? JSON.parse(options.shareInfo) : null;
    this.getCurrentUserName();
    wx.hideShareMenu();
    if (shareInfo){
      this.data.productImg = shareInfo.productImg;
      this.data.qrcodeImg = shareInfo.qrcodeImg;
      this.data.product.productName = shareInfo.productName;
      this.data.sourceText = shareInfo.productName;
      this.data.product.price = shareInfo.minSalePrice ? shareInfo.minSalePrice : null;
      this.data.product.productId = shareInfo.productId;
      this.data.product.type = shareInfo.type;
      this.downloadProductImg();
    }
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {

  },
  //获取登录用户系信息
  getCurrentUserName(){
    let userInfo = wx.getStorageSync('_baseUserInfo') ? wx.getStorageSync('_baseUserInfo') : null;
    if (!userInfo){
      this.data.username = '匿名';
    }
    else{
      this.data.username = userInfo.member.name;
    }

    this.setData({
      username : this.data.username
    });
  },
  //下载商品图
  downloadProductImg() {
    wx.showLoading({
      title: '生成中...',
      mask: true,
    });
    var that = this;
    let productImage = this.data.productImg;
    wx.downloadFile({
      url: productImage,
      success: function (res) {
        if (res.statusCode === 200) {
          var productSrc = res.tempFilePath;
          that.calculateImg(productSrc, function (data) {
            that.getQrCode(productSrc, data);
          });
        }
        else {
          wx.showToast({
            title: '产品图片下载失败！',
            icon: 'none',
            duration: 2000,
            success: function () {
              var productSrc = "";
              that.getQrCode(productSrc);
            }
          })
        }
      },
      fail: function () {
        wx.hideLoading();
        wx.showToast({
          title: '产品图片下载失败！',
          icon: 'none',
          duration: 2000
        });
      },
    })

  },
  //下载二维码图
  getQrCode(productSrc, productImgInfo = "") {
    var that = this;
    let qrcodeImg = this.data.qrcodeImg;
    wx.downloadFile({
      url: qrcodeImg,
      success: function (res) {
        if (res.statusCode === 200) {
          var qrcodeUrl = res.tempFilePath;
          that.downloadShareLogo(function () {
            that.sharePosteCanvas(productSrc, qrcodeUrl, productImgInfo);
          });
        }
        else {
          wx.showToast({
            title: '二维码下载失败！',
            icon: 'none',
            duration: 2000,
            success: function () {
              var qrcodeUrl = "";
              that.downloadShareLogo(function () {
                that.sharePosteCanvas(productSrc, qrcodeUrl, productImgInfo);
              });
            }
          })
        }
      },
      fail: function () {
        wx.hideLoading();
        wx.showToast({
          title: '二维码下载失败！',
          icon: 'none',
          duration: 2000
        });
      },
    })
  },
  //下载商户logo
  downloadShareLogo(cb) {
    let self = this;
    let shareLogo = self.data.shareLogo;
    wx.downloadFile({
      url: shareLogo,
      success: function (res) {
        wx.hideLoading();
        if (res.statusCode === 200) {
          var codeSrc = res.tempFilePath;
          self.data.tempShareLogo = codeSrc;
        }
        else {
          self.data.tempShareLogo = '';
        }

        cb && cb();
      },
      fail: function (res) {
        wx.hideLoading();
        wx.showToast({
          title: '二维码下载失败！',
          icon: 'none',
          duration: 2000,
        })
      }
    })
  },
  //计算图片
  calculateImg(src, cb) {
    var that = this;
    wx.getImageInfo({
      src: src,
      success(res) {
        cb(res);
      }
    })
  },
  //图片自适应大小
  getImageSizeByAspectFit(imageSize, w, h) {
    var scale, imageHeight, imageWidth;
    scale = imageSize.width / imageSize.height;
    imageHeight = w / scale;
    if (imageHeight > h) {
      imageWidth = h * scale;
      imageSize.width = imageWidth;
      imageSize.height = h;
    } else {
      imageSize.width = w;
      imageSize.height = imageHeight;
    }
    // console.log('改变imageSize', imageSize.width, imageSize.height)
    return imageSize;
  },
  //生成canvas
  sharePosteCanvas(productSrc, qrcodeUrl, productImgInfo) {
    const self = this;
    const ctx = wx.createCanvasContext('myCanvas', this)
    // 绘制背景
    const canvas_W = rpx2px(deviceWidth * 2)
    console.log(deviceHeight)
    console.log(ratio)
    if (ratio < 0.55) {
      self.data.height = '1180rpx';
      deviceHeight = 1180;
    }
    else if (ratio > 0.62) {
      deviceHeight = 1200;
      self.data.height = '1200rpx';
    }
    else {
      deviceHeight = 1120;
      self.data.height = '1120rpx';
    }

    self.setData({
      height: self.data.height
    });

    const canvas_H = rpx2px(deviceHeight)
    ctx.setFillStyle('#ffffff')
    //画一个圈
    // ctx.setShadow(0, canvas_H, 20, 'black')
    ctx.fillRect(0, 0, canvas_W, canvas_H);
    //分享商户logo和
    let width = '', height = '';
    if (productImgInfo.width > deviceWidth) {
      width = deviceWidth;
      height = parseInt(productImgInfo.height * (deviceWidth / productImgInfo.width));
    }
    else {
      width = productImgInfo.width;
      height = productImgInfo.height;
    }

    let imageSize = self.getImageSizeByAspectFit(productImgInfo, deviceWidth, height);

    //绘制头部部分
    // self.data.tempShareLogo
    if (self.data.tempShareLogo) {
      ctx.drawImage(self.data.tempShareLogo, rpx2px(30), rpx2px(50), rpx2px(100), rpx2px(100));
    }
    //绘制文案
    ctx.setFontSize(16);
    ctx.setFillStyle('#000000');
    ctx.setTextAlign('left');
    ctx.fillText(self.data.shareTitle ? self.data.shareTitle : '小程序分享' , rpx2px(140), rpx2px(90));
    //设置分享标题文案
    ctx.setFontSize(14);
    ctx.setFillStyle('#999999');
    ctx.setTextAlign('left');
    let shareText = '';
    if (this.data.product.type == 'spread'){
      ctx.fillText(self.data.username + '给您推荐了一些好东西', rpx2px(140), rpx2px(130));
    }
    else{
      ctx.fillText(self.data.username + '给您分享了一个好东西', rpx2px(140), rpx2px(130));
    }

    //绘制商品图片
    if (productSrc) {
      //计算出绘制商品图左右边距
      console.log(imageSize.height)
      let fiexLeft = parseInt(deviceWidth - width) / 2;
      ctx.drawImage(productSrc, rpx2px(30 + fiexLeft * 2), rpx2px(170), imageSize.width - 30, imageSize.height-30);
    }

    //绘制商品价格 单位是分
    if (self.data.product.price) {
      let price = parseFloat(self.data.product.price / 10 / 10).toFixed(2);
      ctx.setFontSize(12);
      ctx.setFillStyle('red');
      ctx.setTextAlign('left');
      if (!isIPX){
        ctx.fillText('￥', rpx2px(30), rpx2px(190 + (deviceWidth - 30) * 2));
      }
      else{
        ctx.fillText('￥', rpx2px(30), rpx2px(280 + (imageSize.height - 30) * 2));
      }
      // if (ratio < 0.55) {
      //   ctx.fillText('￥', rpx2px(30), rpx2px(190 + (imageSize.height - 30) * 2));
      // }
      // else if (ratio > 0.62) {
      //   ctx.fillText('￥', rpx2px(30), rpx2px(240 + (imageSize.height-30) * 2));
      // }
      // else {
      //   ctx.fillText('￥', rpx2px(30), rpx2px(180 + (imageSize.height-30) * 2));
      // }

      ctx.setFillStyle('red');
      ctx.setTextAlign('left');
      ctx.font = 'bold 24px sans-serif';
      if(!isIPX){
        ctx.fillText(price, rpx2px(60), rpx2px(190 + (deviceWidth - 30) * 2));
      }
      else{
        ctx.fillText(price, rpx2px(60), rpx2px(280 + (imageSize.height - 30) * 2));
      }
      // if (ratio < 0.55) {
      //   ctx.fillText(price, rpx2px(60), rpx2px(190 + (imageSize.height - 30) * 2));
      // }
      // else if (ratio > 0.62) {
      //   ctx.fillText(price, rpx2px(60), rpx2px(240 + (imageSize.height -30) * 2));
      // }
      // else {
      //   ctx.fillText(price, rpx2px(60), rpx2px(180 + (imageSize.height -30) * 2));
      // }
    }
    else{
      ctx.setFillStyle('#333333');
      ctx.setTextAlign('left');
      ctx.font = 'bold 16px sans-serif';

      if (ratio < 0.55) {
        ctx.fillText('推广商品', rpx2px(60), rpx2px(250 + (imageSize.height - 30) * 2));
      }
      else if (ratio > 0.62) {
        ctx.fillText('推广商品', rpx2px(60), rpx2px(240 + (imageSize.height - 30) * 2));
      }
      else {
        ctx.fillText('推广商品', rpx2px(60), rpx2px(180 + (imageSize.height - 30) * 2));
      }
    }

    //绘制商品名称
    if (self.data.product.productName) {
      ctx.setFontSize(15);
      ctx.setFillStyle('#333333');
      ctx.setTextAlign('left');
      let textArr = setTextLine(ctx, self.data.product.productName, 3, 400);
      textArr.forEach((item, index) => {
        if(!isIPX){
          ctx.fillText(item, rpx2px(30), rpx2px(250 + (deviceWidth - 30) * 2) + rpx2px(index * 35));
        }
        else{
          ctx.fillText(item, rpx2px(30), rpx2px(330 + (deviceWidth - 30) * 2) + rpx2px(index * 35));
        }
        
        // if (ratio < 0.55) {
        //   ctx.fillText(item, rpx2px(30), rpx2px(280 + (imageSize.height -30) * 2) + rpx2px(index * 35));
        // }
        // else if (ratio > 0.62) {
        //   ctx.fillText(item, rpx2px(30), rpx2px(320 + (imageSize.height -30) * 2) + rpx2px(index * 35));
        // }
        // else {
        //   ctx.fillText(item, rpx2px(30), rpx2px(250 + (imageSize.height -30) * 2) + rpx2px(index * 35));
        // }
      })
    }

    //绘制二维码
    if (qrcodeUrl) {
      ctx.setFontSize(12);
      ctx.setFillStyle('#999999');
      ctx.setTextAlign('left');
      if (ratio < 0.55) {
        ctx.drawImage(qrcodeUrl, deviceWidth - 100, (imageSize.height - 30) + 125, 80, 80);
        ctx.fillText('长按识别小程序', deviceWidth - 100, (imageSize.height -30) + 225);
      }
      else if (ratio > 0.62) {
        ctx.drawImage(qrcodeUrl, deviceWidth - 100, (imageSize.height -30) + 120, 80, 80);
        ctx.fillText('长按识别小程序', deviceWidth - 100, (imageSize.height -30) + 220);
      }
      else {
        ctx.drawImage(qrcodeUrl, deviceWidth - 100, (imageSize.height -30) + 120, 80, 80);
        ctx.fillText('长按识别小程序', deviceWidth - 100, (imageSize.height -30) + 220);
      }

    }

    ctx.draw(false, () => {
      wx.canvasToTempFilePath({
        canvasId: 'myCanvas',
        quality: 1,
        success: result => {
          console.log(result)
          self.data.btnIsDisabled = false;
          self.data.canvasTempFileUrl = result.tempFilePath;
          self.setData({
            canvasTempFileUrl: self.data.canvasTempFileUrl,
            btnIsDisabled: self.data.btnIsDisabled
          });
        }
      }, self)
    })

    wx.hideLoading();
  },
  //按钮保存海报
  onTapSaveImg() {
    var that = this;
    wx.showLoading({
      title: '正在保存',
      mask: true,
    });

    setTimeout(function () {
      var tempFilePath = that.data.canvasTempFileUrl;
      wx.saveImageToPhotosAlbum({
        filePath: tempFilePath,
        success(res) {
          wx.hideLoading();
          wx.showModal({
            content: '图片已保存到相册，赶紧晒一下吧~',
            showCancel: false,
            confirmText: '好的',
            confirmColor: '#333',
            success: function (res) {
              if (res.confirm) { }
            },
            fail: function (res) {
              console.log(res)
            }
          })
        },
        fail: function (res) {
          wx.hideLoading();
          wx.showToast({
            title: res.errMsg,
            icon: 'none',
            duration: 2000
          })
        }
      })
    }, 1000);
  },
  //编辑文案
  onTapEditShareContent(){
    this.data.isInput = true;
    this.setData({
      inputText : this.data.product.productName,
      isInput : this.data.isInput
    });
  },
  //输入
  onShareTextInput(e){
    let value = e.detail.value;
    this.data.inputText = value;
  },
  //取消
  onTapCancal(){
    this.setData({
      isInput : false
    });
  },
  //确认
  onTapSure(){
    if(!this.data.inputText){
      wx.showToast({
        title: '请输入分享文案',
        icon : 'none'
      });
      return ;
    }

    this.data.product.productName = this.data.inputText;

    //重新绘制一下图
    this.setData({
      isInput : false
    },() => {
      this.downloadProductImg();
    });
  },
  //重置文案
  onTapReset(){
    this.data.product.productName = this.data.sourceText;
    //重新绘制一下图
    this.setData({
      isInput: false
    }, () => {
      this.downloadProductImg();
    });
  }
});